==> jboss-wfk-2.0.0-errai-tech-preview-src.zip: jboss-wfk-2.0.0/src/errai-2.0.1.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/client/shared/QueryParamTestService.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.client.shared;

import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.HEAD;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;

/**
 * This service is used to test support for query parameters (@QueryParam).
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
@Path("/test/queryparam")
public interface QueryParamTestService {

  @GET
  @Path("/1")
  public Long getWithQueryParam(@QueryParam("id") long id);

  @GET
  @Path("/2")
  public String getWithStringQueryParam(@QueryParam("id") String id);
  
  @GET 
  @Path("/3")
  public String getWithMultipleQueryParams(@QueryParam("id1") long id1, @QueryParam("id2") long id2);

  @POST
  public int postWithQueryParam(@QueryParam("id") int id);

  @PUT
  public Double putWithQueryParam(@QueryParam("id") Double id);

  @DELETE
  public short deleteWithQueryParam(@QueryParam("id") short id);
  
  @HEAD
  public void headWithQueryParam(@QueryParam("id") long id);
}

==> jboss-wfk-2.1.0-errai-tech-preview-src.zip: jboss-wfk-2.1.0/src/errai-2.1.0.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/client/shared/QueryParamTestService.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.client.shared;

import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.HEAD;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;

/**
 * This service is used to test support for query parameters (@QueryParam).
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
@Path("/test/queryparam/")
public interface QueryParamTestService {

  @GET
  @Path("/1")
  public Long getWithQueryParam(@QueryParam("id") long id);

  @GET
  @Path("/2")
  public String getWithStringQueryParam(@QueryParam("id") String id);
  
  @GET 
  @Path("/3")
  public String getWithMultipleQueryParams(@QueryParam("id1") long id1, @QueryParam("id2") long id2);

  @POST
  public int postWithQueryParam(@QueryParam("id") int id);

  @PUT
  public Double putWithQueryParam(@QueryParam("id") Double id);

  @DELETE
  public short deleteWithQueryParam(@QueryParam("id") short id);
  
  @HEAD
  public void headWithQueryParam(@QueryParam("id") long id);
}
